# Changelog

## [Unreleased][]

[Unreleased]: https://github.com/chaostoolkit/chaosplatform-scheduling/compare/0.1.2...HEAD

## [0.1.2][] - 2018-01-12

[0.1.2]: https://github.com/chaostoolkit/chaosplatform-scheduling/compare/0.1.1...0.1.2

### Changed

-  Pin only a minimum version of each dependency for composability

## [0.1.1][] - 2018-11-01

[0.1.1]: https://github.com/chaostoolkit/chaosplatform-scheduling/compare/0.1.0...0.1.1

### Changed

-   Bump sqlalchemy dependencies to match other services requirements

## [0.1.0][] - 2018-11-01

[0.1.0]: https://github.com/chaostoolkit/chaosplatform-scheduling/tree/0.1.0

### Added

-   Initial release